@@ -1,5 +1,7 @@
 """
-Main interface for elb service literal definitions.
+Type annotations for elb service literal definitions.
+
+[Open documentation](./literals.md)
 
 Usage::
 
